@@ -1,7 +1,8 @@
 from comfy_models.base.comfy_utils import Config
 
 config = Config(
-    name="flux_dev",
+    id="flux_dev",
+    name="Flux (Dev)",
     # memroy snspshot
     models_to_cache=[
         "unet/flux1-dev.sft",
@@ -14,4 +15,5 @@ config = Config(
     # nodes to preload during comfyui cold start
     # nodes_to_preload=["UNETLoader", "VAELoader", "DualCLIPLoader"],
     warmup_workflow=True,
-)
\ No newline at end of file
+    preview_image="https://comfy-deploy-output-dev.s3.us-east-2.amazonaws.com/outputs/runs/b5afa7eb-a15f-4c45-a95c-d5ce89cb537f/image.jpeg",
+)
