@@ -8,7 +8,7 @@ from comfy_models.workflows import (
 )
 from comfy_models.workflows.flux_dev.config import config
 
-APP_NAME = config.name
+APP_NAME = config.id
 app = modal.App(APP_NAME)
 
 
